@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util;
 
-our $DATE = '2014-12-27'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-07-30'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -36,6 +36,9 @@ The criteria are:
   something like `use Perinci::CmdLine`;
 
 _
+    args_rels => {
+        req_one => [qw/filename string/],
+    },
     args => {
         filename => {
             summary => 'Path to file to be checked',
@@ -45,6 +48,7 @@ _
 Either `filename` or `string` must be specified.
 
 _
+            pos => 0,
         },
         string => {
             summary => 'Path to file to be checked',
@@ -72,6 +76,8 @@ sub detect_perinci_cmdline_script {
     my $yesno = 0;
     my $reason = "";
 
+    my $meta = {};
+
     my $str = $args{string};
   DETECT:
     {
@@ -119,15 +125,56 @@ sub detect_perinci_cmdline_script {
             $reason = "Marked with # NO_PERINCI_CMDLINE_SCRIPT directive";
             last;
         }
-        if ($str =~ /^\s*(use|require)\s+Perinci::CmdLine(|::Any|::Lite)/m) {
+        if ($str =~ /^\s*(use|require)\s+
+                     (Perinci::CmdLine(|::Any|::Lite|::Classic))\b/mx) {
             $yesno = 1;
+            $meta->{'func.module'} = $2;
+            last DETECT;
+        }
+        if ($str =~ /^# PERICMD_INLINE_SCRIPT: (.+)/m) {
+            $yesno = 1;
+            $meta->{'func.module'} = 'Perinci::CmdLine::Inline';
+            $meta->{'func.is_inline'} = 1;
+
+            my $pericmd_inline_attrs = $1;
+            my ($pericmd_inline_version) =
+                $str =~ /Perinci::CmdLine::Inline version ([0-9._]+)/;
+            $meta->{'func.notes'} //= [];
+            $meta->{'func.pericmd_inline_version'} = $pericmd_inline_version;
+            if (!$pericmd_inline_version) {
+                push @{ $meta->{'func.notes'} },
+                    "Can't detect version of Perinci::CmdLine::Inline version";
+            }
+            if ($pericmd_inline_version < 0.17) {
+                push @{ $meta->{'func.notes'} }, join(
+                    "",
+                    "Won't parse # PERICMD_INLINE_SCRIPT attributes ",
+                    "because prior to Perinci::CmdLine::Inline 0.17, ",
+                    "the attributes are dumped as Perl instead of JSON ",
+                    "so it's unsafe to parse",
+                );
+            } else {
+                require JSON;
+                eval { $pericmd_inline_attrs =
+                           JSON::decode_json($pericmd_inline_attrs) };
+                if ($@) {
+                    push @{ $meta->{'func.notes'} },
+                        "Can't parse # PERICMD_INLINE_SCRIPT attributes: $@";
+                } else {
+                    $meta->{'func.pericmd_inline_attrs'} =
+                        $pericmd_inline_attrs;
+                }
+            }
+
             last DETECT;
         }
         $reason = "Can't find any statement requiring Perinci::CmdLine".
             " module family";
     } # DETECT
 
-    [200, "OK", $yesno, {"func.reason"=>$reason}];
+    $meta->{'func.reason'} = $reason;
+
+    [200, "OK", $yesno, $meta];
 }
 
 1;
@@ -145,7 +192,7 @@ Perinci::CmdLine::Util - Utility routines related to Perinci::CmdLine
 
 =head1 VERSION
 
-This document describes version 0.06 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2014-12-27.
+This document describes version 0.07 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2015-07-30.
 
 =head1 SYNOPSIS
 
@@ -156,8 +203,9 @@ This document describes version 0.06 of Perinci::CmdLine::Util (from Perl distri
 
 =head2 detect_perinci_cmdline_script(%args) -> [status, msg, result, meta]
 
-Detect whether a file is a Perinci::CmdLine-based CLI script.
+{en_US Detect whether a file is a Perinci::CmdLine-based CLI script}.
 
+{en_US 
 The criteria are:
 
 =over
@@ -171,6 +219,7 @@ bit set;
 
 =item * either: must be perl script (shebang line contains 'perl') and must contain
 something like C<use Perinci::CmdLine>;
+}
 
 =back
 
@@ -180,24 +229,26 @@ Arguments ('*' denotes required arguments):
 
 =item * B<filename> => I<str>
 
-Path to file to be checked.
+{en_US Path to file to be checked}.
 
+{en_US 
 Either C<filename> or C<string> must be specified.
+}
 
 =item * B<include_noexec> => I<bool> (default: 1)
 
-Include scripts that do not have +x mode bit set.
+{en_US Include scripts that do not have +x mode bit set}.
 
 =item * B<string> => I<buf>
 
-Path to file to be checked.
+{en_US Path to file to be checked}.
 
+{en_US 
 Either C<file> or C<string> must be specified.
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -207,7 +258,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =for Pod::Coverage ^()$
 
@@ -237,7 +288,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
